| Title: | OpenCL Backend Scaffold for amatrix |
|---|---|
| Description: | OpenCL backend package for amatrix. Registers a backend contract implementation and provides a safe mock bridge that can be built with or without OpenCL and CLBlast present at compile time. |
| Authors: | Ben Buchsbaum [aut, cre] |
| Maintainer: | Ben Buchsbaum <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-07-02 15:15:04 UTC |
| Source: | https://github.com/bbuchsbaum/amatrix |